@@ -6,32 +6,6 @@ use warnings;
 use Encode 'encode', 'decode';
 use Carp 'confess';
 
-sub to_string {
-  my $bin = SPVM::ExchangeAPI::to_bin(@_);
-  
-  my $string = decode('UTF-8', $bin);
-  
-  return $string;
-}
-
-sub to_strings {
-  my $elems = SPVM::ExchangeAPI::to_elems(@_);
-  
-  my $strs = [];
-  
-  for (my $i = 0; $i < @$elems; $i++) {
-    my $elem = $elems->[$i];
-    if (defined $elem) {
-      $strs->[$i] = $elem->to_string;
-    }
-    else {
-      $strs->[$i] = undef;
-    }
-  }
-  
-  return $strs;
-}
-
 sub new_byte_array_from_string {
   my ($env, $string) = @_;
   
@@ -40,10 +14,6 @@ sub new_byte_array_from_string {
   return SPVM::ExchangeAPI::new_byte_array_from_bin($env, $bin);
 }
 
-sub new_string { SPVM::ExchangeAPI::new_byte_array_from_string(@_) }
-
-sub new_string_from_bin { SPVM::ExchangeAPI::new_byte_array_from_bin(@_) }
-
 sub new_object_array {
   my ($env, $type_name, $elems) = @_;
   
@@ -175,6 +145,8 @@ SPVM::ExchangeAPI - SPVM Exchange API
 
 =head2 memory_blocks_count
 
+=head2 new_string_array
+
 =head2 new_byte_array
 
 =head2 new_byte_array_from_bin
@@ -213,10 +185,6 @@ SPVM::ExchangeAPI - SPVM Exchange API
 
 =head2 set_exception
 
-=head2 to_bin
+=head2 array_to_bin
 
-=head2 to_elems
-
-=head2 to_string
-
-=head2 to_strings
+=head2 array_to_elems
